import React from 'react';
import ReactDOM from 'react-dom';

import AriaMenu from './components/aria-menu.jsx';
import '../styles/app.scss';

export default class Athena extends React.Component {

    constructor(props) {
        super(props);

        this.state = {
            email: '',
            password: '',
            loginValid: true
        }
    }

    updateEmail = (ev) => {
        this.setState({
            email: ev.target.value
        });
    }
    
    updatePassword = (ev) => {
        this.setState({
            password: ev.target.value
        });
    }

    handleLogin = (ev) => {
        ev.preventDefault();
        if (this.state.email === 'test@example.com' && this.state.password === 'password') {
            this.setState({
                loginValid: true
            });
        } else {
            this.setState({
                loginValid: false
            });
        }
    }

    /* 
        die render-Funktion ist die einzige Funktion, welche eine React-Komponente benoetigt 
        sie muss mindestens ein React.createElement zurueck geben
        jsx wandelt den Beispielcode automatisch in einen createElement call um 
        um die Verwendung von jsx zu spezifizieren werden die runden Klammern benutzt
    */
    render() {
        /*
            reagiert auf den den state loginValid aus der handleLogin funktion
        */
        let errorTag = null;
        let errorLabel = null;
        let errorInput = null;
        if (!this.state.loginValid) {
            errorTag = (
                <span className="form-error is-visible">No user exists with the e-mail address {this.state.email} or the password is incorrect.</span>
            );
            errorLabel = 'is-invalid-label';
            errorInput = 'is-invalid-input';
        }
        return (
            /* 
                anstelle von class aus HTML benutzt JSX className
                alle Attribute werden in camelCase geschrieben: tabindex wird zu tabIndex
            */
            <div>
            <header className="grid-x">
            <AriaMenu label="Main" class="horizontal">
              <li className="menu-text">Athena - Study Portal</li>
              <li><a href="" role="menuitem" tabIndex="0" className="active">My Modules</a></li>
              <li><a href="" role="menuitem" tabIndex="-1">My Exams</a></li>
            </AriaMenu>
            <AriaMenu label="User" class="horizontal">
              <li><a href="profile.html" role="menuitem" tabIndex="0">Profile</a></li>
              <li><a href="login.html" role="menuitem" tabIndex="-1">Logout</a></li>
            </AriaMenu>
            </header>
            <main className="grid-container-x small callout">
              <h1>Login</h1>
              <form action="index.html" onSubmit={this.handleLogin}>
                <div>
                  <label className={errorLabel}>E-Mail Address
                      {/*
                        {this.state.email} verwendet bei der Initialisierung der Seite den Inhalt von email aus dem Konstruktor oben 
                        wir verknuepfen eine Funktion: updateEmail um die Eingabe des Nutzers in den Konstruktor zu geben
                      */}
                  <input type="email" name="email" placeholder="Your e-mail address" tabIndex="1" required="required" value={this.state.email} onChange={this.updateEmail} className={errorInput} />
                  {errorTag}
                  </label>
                </div>
                <div>
                  <label className={errorLabel}>Password
                  <input type="password" name="password" placeholder="Your password" tabIndex="2" required="required" value={this.state.password} onChange={this.updatePassword} className={errorInput}/>
                  {/*
                        {errorTag} ist null wenn der login Erfolgreich war und enthält ein <span>-Element , wie oben definiert, wenn der login fehlerhaft war
                        {errorInput und errorLabel} passen sich ebenso an den Erfolg oder Misserfolg des Logins bzw. der bool-Variable loginValid
                  */}
                  {errorTag}
                  </label>
                </div>
                <div className="text-right">
                  <button tabIndex="3">Login</button>
                </div>
              </form>
            </main>
            <footer>
              &copy; 2020 - Max Mustermann (<a href="mailto:mustermann@musteradresse.de" tabIndex="0">mustermann@musteradresse.de</a>)
            </footer>
            </div>
        );
    }
}

export function install(attachmentPoint, options, callback) {
    ReactDOM.render(<Athena/>, attachmentPoint);
}

/* ReactDom.render bringt die Komponente, die oben definiert wurde in das Element mit der ID 'app-entry-point */
ReactDOM.render(<Athena/>, document.getElementById('app-entry-point'));



